@@ -1,29 +1,16 @@
 /*
-    Copyright (C) 2016 David Rosca <nowrep@gmail.com>
+    SPDX-FileCopyrightText: 2016 David Rosca <nowrep@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <QTest>
 #include <QStandardPaths>
+#include <QTest>
 
-#include <KSharedConfig>
 #include <KConfigGroup>
 #include <KIconEngine>
 #include <KIconLoader>
+#include <KSharedConfig>
 
 extern KICONTHEMES_EXPORT int kiconloader_ms_between_checks;
 
@@ -40,8 +27,9 @@ private Q_SLOTS:
         const QString cacheFile = QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation) + QStringLiteral("/icon-cache.kcache");
         QFile::remove(cacheFile);
 
+        // we have Breeze via it's library and it inherits hicolor
         KConfigGroup cg(KSharedConfig::openConfig(), "Icons");
-        cg.writeEntry("Theme", "oxygen");
+        cg.writeEntry("Theme", "breeze");
         cg.sync();
 
         QDir testDataDir(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation));
@@ -52,11 +40,12 @@ private Q_SLOTS:
 
         testIconsDir.removeRecursively();
 
-        // set up a minimal Oxygen icon theme, in case it is not installed
-        QVERIFY(testIconsDir.mkpath(QStringLiteral("oxygen/22x22/apps")));
-        QVERIFY(QFile::copy(QStringLiteral(":/oxygen.theme"), testIconsDir.filePath(QStringLiteral("oxygen/index.theme"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("oxygen/22x22/apps/kde.png"))));
-        QVERIFY(testIconsDir.mkpath(QStringLiteral("oxygen/22x22/actions"))); // we need the dir to exist since KIconThemes caches mDirs
+        // set up a minimal hicolor icon theme, in case it is not installed
+        QVERIFY(testIconsDir.mkpath(QStringLiteral("hicolor/22x22/apps")));
+        QVERIFY(QFile::copy(QStringLiteral(":/oxygen.theme"), testIconsDir.filePath(QStringLiteral("hicolor/index.theme"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("hicolor/22x22/apps/kde.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("hicolor/22x22/apps/org.kde.testapp.png"))));
+        QVERIFY(testIconsDir.mkpath(QStringLiteral("hicolor/22x22/actions"))); // we need the dir to exist since KIconThemes caches mDirs
 
         // Clear SHM cache
         KIconLoader::global()->reconfigure(QString());
@@ -76,6 +65,17 @@ private Q_SLOTS:
         QVERIFY2(icon.name().isEmpty(), qPrintable(icon.name()));
     }
 
+    void testFallbackIconName()
+    {
+        QIcon icon(new KIconEngine(QStringLiteral("kde-specific-icon"), KIconLoader::global()));
+        QVERIFY(!icon.isNull());
+        QCOMPARE(icon.name(), QStringLiteral("kde"));
+
+        QIcon icon2(new KIconEngine(QStringLiteral("org.kde.testapp-specific-icon"), KIconLoader::global()));
+        QVERIFY(!icon2.isNull());
+        QCOMPARE(icon2.name(), QStringLiteral("org.kde.testapp"));
+    }
+
     void testUnknownIconNotCached() // QIcon version of the test in kiconloader_unittest.cpp
     {
         // This is a test to ensure that "unknown" icons are cached as unknown
@@ -84,13 +84,12 @@ private Q_SLOTS:
 
         kiconloader_ms_between_checks = 500000;
 
-        QString actionIconsSubdir = QStringLiteral("oxygen/22x22/actions");
+        QString actionIconsSubdir = QStringLiteral("hicolor/22x22/actions");
         QVERIFY(testIconsDir.mkpath(actionIconsSubdir));
         QString actionIconsDir = testIconsDir.filePath(actionIconsSubdir);
 
         QString nonExistingIconName = QStringLiteral("asvdfg_fhqwhgds");
-        QString newIconPath = actionIconsDir + QLatin1String("/")
-                              + nonExistingIconName + QLatin1String(".png");
+        QString newIconPath = actionIconsDir + QLatin1String("/") + nonExistingIconName + QLatin1String(".png");
         QFile::remove(newIconPath);
 
         // Find a non-existent icon
@@ -119,7 +118,6 @@ private Q_SLOTS:
         QIcon icon3(new KIconEngine(nonExistingIconName, KIconLoader::global()));
         QVERIFY(!icon3.isNull());
         QCOMPARE(icon3.name(), nonExistingIconName);
-
     }
 
     void testCenterIcon()
@@ -136,6 +134,27 @@ private Q_SLOTS:
         // center horizontally
         QVERIFY(icon.pixmap(26, 22).toImage().copy(2, 0, 22, 22) == image);
     }
+
+    void testNonSquareSvg()
+    {
+        QIcon icon(new KIconEngine(QStringLiteral(":/nonsquare.svg"), KIconLoader::global()));
+        QVERIFY(!icon.isNull());
+
+        // verify we get the content fully fitted in when asking for the right aspect ratio
+        const QImage image = icon.pixmap(40, 20).toImage();
+        QCOMPARE(image.pixelColor(0, 0), QColor(255, 0, 0));
+        QCOMPARE(image.pixelColor(19, 9), QColor(255, 0, 0));
+        QCOMPARE(image.pixelColor(39, 0), QColor(0, 255, 0));
+        QCOMPARE(image.pixelColor(20, 9), QColor(0, 255, 0));
+        QCOMPARE(image.pixelColor(0, 19), QColor(0, 0, 255));
+        QCOMPARE(image.pixelColor(19, 10), QColor(0, 0, 255));
+        QCOMPARE(image.pixelColor(39, 19), QColor(255, 255, 0));
+        QCOMPARE(image.pixelColor(20, 10), QColor(255, 255, 0));
+
+        // and now with a wrong aspect ratio
+        QCOMPARE(icon.pixmap(40, 40).toImage().convertToFormat(image.format()).copy(0, 10, 40, 20), image);
+    }
+
 private:
     QDir testIconsDir;
 };
